@@ -1,10 +1,10 @@
 package Message::Passing::Input::ZeroMQ;
-use Moose;
+use Moo;
 use ZeroMQ qw/:all/;
 use AnyEvent;
 use Scalar::Util qw/ weaken /;
 use Try::Tiny qw/ try catch /;
-use namespace::autoclean;
+use namespace::clean -except => 'meta';
 
 with qw/
     Message::Passing::ZeroMQ::Role::HasASocket
@@ -21,9 +21,20 @@ sub _socket_type { 'SUB' }
 
 sub _build_socket_hwm { 100000 }
 
+has subscribe => (
+    isa => sub { ref($_[0]) eq 'ARRAY' },
+    is => 'ro',
+    lazy => 1,
+    default => sub { [ '' ] }, # Subscribe to everything!
+);
+
 after setsockopt => sub {
     my ($self, $socket) = @_;
-    $socket->setsockopt(ZMQ_SUBSCRIBE, '');
+    if ($self->socket_type eq 'SUB') {
+        foreach my $sub (@{ $self->subscribe }) {
+            $socket->setsockopt(ZMQ_SUBSCRIBE, $sub);
+        }
+    }
 };
 
 sub _try_rx {
@@ -90,6 +101,13 @@ an input with L<Message::Passing::DSL>.
 
 See L<Message::Passing::ZeroMQ/CONNECTION ATTRIBUTES>
 
+=head2 subscribe
+
+If the input socket is a C<SUB> socket, then the C<ZMQ_SUBSCRIBE>
+socket option will be set once for each value in the subscribe attribute.
+
+Defaults to '', which means all messages are subscribed to.
+
 =head1 SEE ALSO
 
 =over
